## 2.1.2 - 2026-03-18

### 🐛 Fixed

- [#1703](https://github.com/edgarrmondragon/citric/issues/1703) Removed `one_time_pw` from `UserDetails` typed dict since it's only exposed by mistake in older LimeSurvey versions and it's a security bug
